@@ -101,9 +101,11 @@ impl Parse for Args {
                 ty,
                 // Hardcoded external calls
                 external_calls: vec![
+                    // Common calls
                     Ident::new("Ok", Span::call_site()),
                     Ident::new("Err", Span::call_site()),
                     Ident::new("new", Span::call_site()),
+                    // Instrumentation
                     Ident::new("start_timer", Span::call_site()),
                     Ident::new("stop_timer", Span::call_site()),
                     Ident::new("push_syscall_result", Span::call_site()),
@@ -111,9 +113,15 @@ impl Parse for Args {
                 ],
                 // Hardcoded External methods
                 external_methods: vec![
+                    // Common methods
                     Ident::new("into", Span::call_site()),
                     Ident::new("len", Span::call_site()),
                     Ident::new("ok_or", Span::call_site()),
+                    // Pure methods: todo, handle pure methods better
+                    Ident::new("fits_in_lin_mem", Span::call_site()),
+                    Ident::new("fits_in_lin_mem_usize", Span::call_site()),
+                    Ident::new("in_lin_mem", Span::call_site()),
+                    Ident::new("in_lin_mem_usize", Span::call_site()),
                 ],
             });
         }
@@ -137,13 +145,15 @@ impl Fold for Args {
     /// Rewrite calls of the form func(...) => func(..., state)
     /// If the call is in self.external_calls, ignore it
     fn fold_expr_call(&mut self, call: ExprCall) -> ExprCall {
-        //println!("Rewriting fn call {#:?}", call);
+        println!("==> Rewriting fn call {:#?}", call);
+        println!("External calls: {:#?}", self.external_calls);
         // if call is external, ignore it
         for external_call in self.external_calls.iter() {
             let func_name: Result<Ident> = expr_to_ident(*call.func.clone());
             match func_name {
                 Ok(name) => {
                     if name.to_string() == external_call.to_string() {
+                        println!("<== Call to {:#?} is external, skipping", call);
                         return call;
                     }
                 }
@@ -154,25 +164,29 @@ impl Fold for Args {
         let arg = self.var_as_expr();
         let mut new_call = call;
         new_call.args.push(arg);
+        println!("<== Call instrumented: {:#?}", new_call);
         new_call
     }
 
     /// Rewrite method calls of the form o.method(...) => o.method(..., state)
-    /// If the call is in self.external_methodss, ignore it
+    /// If the call is in self.external_methods, ignore it
     fn fold_expr_method_call(&mut self, method_call: ExprMethodCall) -> ExprMethodCall {
+        println!("==> Rewriting method call {:#?}", method_call);
+        println!("External methods: {:#?}", self.external_methods);
         let mut new_method_call = method_call;
         *new_method_call.receiver = self.fold_expr(*new_method_call.receiver);
 
         // If method is external, ignore it
         for external_method in self.external_methods.iter() {
             if new_method_call.method.to_string() == external_method.to_string() {
+                println!("<== Call to {:#?} is external, skipping", new_method_call);
                 return new_method_call;
             }
         }
         // else, add ghost state
         let arg = self.var_as_expr();
         new_method_call.args.push(arg);
-
+        println!("<== Method call instrumented: {:#?}", new_method_call);
         new_method_call
     }
 
@@ -276,12 +290,12 @@ pub fn external_methods(_args: TokenStream, input: TokenStream) -> TokenStream {
     input
 }
 
-#[proc_macro_attribute]
-pub fn dummy_macro(args: TokenStream, input: TokenStream) -> TokenStream {
-    println!("args: \"{}\"", args.to_string());
-    println!("input: \"{}\"", input.to_string());
-    input
-}
+// #[proc_macro_attribute]
+// pub fn dummy_macro(args: TokenStream, input: TokenStream) -> TokenStream {
+//     println!("args: \"{}\"", args.to_string());
+//     println!("input: \"{}\"", input.to_string());
+//     input
+// }
 
 // #[proc_macro_attribute]
 // pub fn fuzz_trusted(args: TokenStream, input: TokenStream) -> TokenStream {
